[PATCH][next] dmaengine: loongson: Fix spelling mistake "Looongson" -> "Looogson"

Colin Ian King <[email protected]>
Newsgroups org.kernel.vger.kernel-janitors,org.kernel.vger.dmaengine,org.kernel.vger.linux-kernel
Message-ID <[email protected]>
There are a couple of spelling mistakes, one in a comment block and
one in a module description. Fix them.

Signed-off-by: Colin Ian King <[email protected]>
---
 drivers/dma/loongson/loongson2-apb-cmc-dma.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/drivers/dma/loongson/loongson2-apb-cmc-dma.c b/drivers/dma/loongson/loongson2-apb-cmc-dma.c
index 2f2ef51e41b6..1c9a542edc85 100644
--- a/drivers/dma/loongson/loongson2-apb-cmc-dma.c
+++ b/drivers/dma/loongson/loongson2-apb-cmc-dma.c
@@ -1,6 +1,6 @@
 // SPDX-License-Identifier: GPL-2.0-or-later
 /*
  * Looongson-2 Chain Multi-Channel DMA Controller driver
  *
  * Copyright (C) 2024-2026 Loongson Technology Corporation Limited
  */
@@ -725,6 +725,6 @@ static struct platform_driver loongson2_cmc_dma_driver = {
 };
 module_platform_driver(loongson2_cmc_dma_driver);
 
-MODULE_DESCRIPTION("Looongson-2 Chain Multi-Channel DMA Controller driver");
+MODULE_DESCRIPTION("Loongson-2 Chain Multi-Channel DMA Controller driver");
 MODULE_AUTHOR("Loongson Technology Corporation Limited");
 MODULE_LICENSE("GPL");
@@ -1,6 +1,6 @@
 // SPDX-License-Identifier: GPL-2.0-or-later
 /*
- * Looongson-2 Chain Multi-Channel DMA Controller driver
+ * Loongson-2 Chain Multi-Channel DMA Controller driver
  *
  * Copyright (C) 2024-2026 Loongson Technology Corporation Limited
-- 
2.53.0
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.